#!/bin/sh
#
# DO NOT RUN THIS SCRIPT BY HAND!!!!!!!
#
# This file is intended to be executed from the q2-wrapper makefile only.
#
# Parameters:
#	$1	BINDIR		Usually /usr/local/bin
#	$2	INSTALLDIR	Usually /usr/games/quake2
#	$3	DOCDIR		Usually /usr/games/quake2/doc
#	$4	EXECPERM	For executables and directories [755]
#	$5	READPERM	For regular files [644]
#	$6	INSTUSER	Files installed as owner $INSTUSER root
#	$7	INSTGROUP	Files installed as group $INSTGROUP root
#	$8	TARBALL		The tarball containing Quake2 as
#				distributed by Id.



BINDIR=$1
INSTALLDIR=$2
DOCDIR=$3
EXECPERM=$5
READPERM=$6
INSTUSER=$7
INSTGROUP=$8
TARBALL=$9


# Error return codes

NORMAL_EXIT=0
PERM_ERR=1
EXEC_ERR=2
MTAB_ERR=3
CD_NOT_MOUNTED=4
NO_TAR=5
MISC_FILE=6

# Filenames...  Don't touch.
MTAB=/etc/mtab
PAKFILE="install/data/baseq2/pak0.pak"
BASE="sys_baseq2"
PLAYERS="sys_players"
VIDEO="sys_video"


if [ `id | sed s/\(/=/ | cut -d= -f2` -ne 0 ] ; then
	echo "ERROR: You must install Quake2 as root."
	echo "INSTALL ABORTED"
	exit $PERM_ERR
fi

if [ -z $9 ] ; then
	echo "Apparently, you're trying to execute this script from the"
	echo "command line.  Let the Makefile do that."
	exit $EXEC_ERR
fi


if [ ! -r $MTAB ] ; then
	echo "ERROR: Can't read mount table to determine mounted CD location."
	echo "Check $MTAB's permissions."
	echo "INSTALL ABORTED"
	exit $MTAB_ERR
fi

CDDIR=`cat $MTAB | grep iso9660 | cut -d " " -f2`
CDDIR_NUM=`cat $MTAB | grep iso9660 | cut -d " " -f2 | wc -l`

if [ $CDDIR_NUM -eq 0 ] ; then
	echo "ERROR: Unable to find a mounted CD."
	echo "Please mount your Quake2 CD somewhere."
	echo "Don't worry where you put it.  I'll find it."
	echo "INSTALL ABORTED"
	exit $CD_NOT_MOUNTED
fi

FOUND_CD=0
for CDDIR in $CDDIR ; do
	if [ -e $CDDIR/$PAKFILE ] ; then
		echo "Found the Quake2 CD in $CDDIR"
		FOUND_CD=1
	fi
done

if [ $FOUND_CD -eq 0 ] ; then
	echo "ERROR: Found one or more mounted CDs, but no Quake2 CD."
	echo "INSTALL ABORTED"
	exit $CD_NOT_MOUNTED
fi


BASEDIR=$INSTALLDIR/$BASE
PLAYERSDIR=$BASEDIR/$PLAYERS
CDPLAYERS="$CDDIR/install/data/baseq2/players"
CDVIDEO="$CDDIR/install/data/video"


echo "Copying data from the Quake2 CD to $INSTALLDIR."
echo "This will take a while..."

mkdir $INSTALLDIR
mkdir $BASEDIR
chown $INSTUSER.$INSTGROUP $BASEDIR
chmod $EXECPERM $BASEDIR

echo "Copying $CDDIR/$PAKFILE to $BASEDIR..."
install -o $INSTUSER -g $INSTGROUP -m $READPERM $CDDIR/$PAKFILE $BASEDIR


# Here begins a disgusting hack intended to deal with the stupid Joliet
# filesystem.

echo "Copying $CDDIR/$CDPLAYERS to $PLAYERSDIR..."

mkdir $PLAYERSDIR
chown $INSTUSER.$INSTGROUP $PLAYERSDIR
chmod $EXECPERM $PLAYERSDIR


echo "  Copying male players..."
mkdir $PLAYERSDIR/male

install -o $INSTUSER -g $INSTGROUP -m $EXECPERM  $CDPLAYERS/male $PLAYERSDIR/male
if [ ! -r $CDDIR/Install/Data/quake2.exe ] ; then
	echo "Hmm...  It looks like your kernel doesn't have Joliet support"
	echo "No problem."
	mv $PLAYERSDIR/male/claymo~1.pcx $PLAYERSDIR/male/claymore_i.pcx
	mv $PLAYERSDIR/male/howitz~1.pcx $PLAYERSDIR/male/howitzer_i.pcx
	mv $PLAYERSDIR/male/nighto~1.pcx $PLAYERSDIR/male/nightops_i.pcx
	mv $PLAYERSDIR/male/pointm~1.pcx $PLAYERSDIR/male/pointman_i.pcx
	mv $PLAYERSDIR/male/rampag~1.pcx $PLAYERSDIR/male/rampage_i.pcx
fi


echo "  Copying female players..."
mkdir $PLAYERSDIR/female

install -o $INSTUSER -g $INSTGROUP -m READPERM  $CDPLAYERS/female $PLAYERSDIR/female

if [ ! -r $CDDIR/Install/Data/quake2.exe ] ; then
	mv $PLAYERSDIR/female/briann~1.pcx $PLAYERSDIR/female/brianna_i.pcx
	mv $PLAYERSDIR/female/jezebe~1.pcx $PLAYERSDIR/female/jezebel_i.pcx
	mv $PLAYERSDIR/female/stilet~1.pcx $PLAYERSDIR/female/stiletto_i.pcx
fi

echo "Copying $CDVIDEO to $BASEDIR..."
cp -r $CDVIDEO $BASEDIR/$VIDEO

echo "Copying files from Quake2 CD finished..."



if [ ! -r  $TARBALL  ] ; then
	echo "ERROR: Can't find or read the Quake2 archive $TARBALL"
	echo "INSTALL ABORTED"
	exit $NO_TAR
fi

TEMPDIR="/tmp/install-quake2-$$"
if [ -e $TEMPDIR ] ; then
	echo "$TEMPDIR already exists.  Moving it to $TEMPDIR-old."
	mv $TEMPDIR $TEMPDIR-old || (echo "cannot move $TEMPDIR"; exit $MISC_FILE
fi

echo "Making temporary directory $TEMPDIR..."
mkdir $TEMPDIR
cp $TARBALL $TEMPDIR

echo "Unpacking $TARBALL..."
cd $TEMPDIR
tar zxfv $TARBALL


# Note that the Quake2 binary is not being installed suid-root 
# as Zoid suggests.
echo "Installing Quake2 executable and libs..."
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM  $TEMPDIR/quake2 $BINDIR
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM  $TEMPDIR/ref_soft.so $INSTALLDIR
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM  $TEMPDIR/ref_softx.so $INSTALLDIR
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM  $TEMPDIR/ref_gl.so $INSTALLDIR
install -o $INSTUSER -g $INSTGROUP -m $EXECPERM  $TEMPDIR/gamei386.so  $BASEDIR

echo "Installing Quake2 documentation..."
mkdir $DOCDIR
chown $INSTUSER.$INSTGROUP $DOCDIR
chmod $EXECPERM $DOCDIR
install -o $INSTUSER -g $INSTGROUP -m READPERM  $TEMPDIR/*.txt $DOCDIR
install -o $INSTUSER -g $INSTGROUP -m READPERM  $TEMPDIR/readme.linux $DOCDIR

